@@ -52,13 +52,13 @@ static char *HTML_SUFFIX="html";
 
 static McString indexHeader("<html><head><TITLE>Table of Contents</TITLE>"
 			    "</head><BODY>\n");
-static McString indexFooter("<I><A HREF=\"HIER.html\"> hierarchy of classes</A></I><P></BODY>");
+static McString indexFooter("<I><A HREF=\"HIER.html\"> hierarchy of classes</A></I><P>");
 
 static McString hierHeader("<html><head><TITLE>Hierarchy ClassDoc</TITLE></head>\n<BODY>\n");
-static McString hierFooter("<I><A HREF=\"aindex.html\"> alphabetic index</A></I><P></BODY>");
+static McString hierFooter("<I><A HREF=\"aindex.html\"> alphabetic index</A></I><P>");
 
 static McString pageHeader("<body>\n");
-static McString pageFooter("<I><A HREF=\"aindex.html\"> alphabetic index</A></I>  <I><A HREF=\"HIER.html\"> hierarchy of classes</A></I><P></BODY>");
+static McString pageFooter("<I><A HREF=\"aindex.html\"> alphabetic index</A></I>  <I><A HREF=\"HIER.html\"> hierarchy of classes</A></I><P>");
 
 
 int makedir(const char *d, int perm)
@@ -129,10 +129,11 @@ int subEntryIsToBeDocumented(Entry *entry)
 	    (entry->doc.length() == entry->memo.length() &&
 	     entry->doc == (const char *)entry->memo))
 	    toBeDocumented = 1;
+    
+	if (alwaysPrintDocSection)
+	    toBeDocumented = 1;
     }
 
-    if (alwaysPrintDocSection)
-	toBeDocumented = 1;
     return toBeDocumented;
 }
 
@@ -478,14 +479,15 @@ void copyright(FILE *f)
   if (banner.length()<=0 && ownBanner==0){
       fprintf (f,"<A HREF=\"http://www.zib.de/Visual/software/doc++/index.html\">"
 	       "<IMG BORDER=0 ALIGN=RIGHT SRC=logo.gif></A>\n");
-      fprintf (f,"<P Align=Center><I>this page has been generated automatically by doc++\n");
-      fprintf (f,"<P Align=Center>(c)opyright by <A HREF=\"http://www.zib.de/zoeckler/\"> Malte  Z&oumlckler</A>, "
+      fprintf (f,"<P Align=Center><I>this page has been generated automatically by doc++</I>\n");
+      fprintf (f,"<P Align=Center><I>(c)opyright by <A HREF=\"http://www.zib.de/zoeckler/\"> Malte  Z&ouml;ckler</A>, "
 	       "<A HREF=\"mailto:wunderling@zib.de\"> Roland Wunderling </A>"
-	       "<br>contact: <A HREF=\"mailto:doc++@zib.de\"> doc++@zib.de </a>");
+	       "<br>contact: <A HREF=\"mailto:doc++@zib.de\"> doc++@zib.de</a></I>");
   } else {
       fprintf (f,"%s\n",(const char *)banner);
       fprintf(f,"<P Align=right><I>generated by <A HREF=\"http://www.zib.de/Visual/software/doc++/index.html\">doc++</A></I>");
   }
+  fprintf (f,"\n</BODY>\n");
 }
 
 extern char *strToHtml(const char *in,char *dest=0, Entry* ct=0,int withLinks=0);
@@ -494,7 +496,8 @@ extern char *seeToHtml(const char *in, Entry* ct=0);
 void	entry2link( McString& u, Entry* ref,const char *linkname)
 {
     Entry *globref = ref ;
-    while( globref->parent != root && !globref->fileName.length())
+    if (globref!=root)
+      while( globref->parent != root && !globref->fileName.length())
 	globref = globref->parent ;
     if( ref->fileName.length()) {
 	u+="<!1><A HREF=\"" ; 
@@ -745,16 +748,16 @@ void showMembers( Entry *k,FILE *f,int links,MemberList *ignore=0)
 		    {"<DT><h3>Public Fields</h3><DD>",PUBL,VARIABLE_SEC},
 		    {"<DT><h3>Public Methods</h3><DD>",PUBL,FUNCTION_SEC},
 		    {"<DT><h3>Public</h3><DD>",PUBL,
-		     ~(CLASS_SEC|VARIABLE_SEC| FUNCTION_SEC)},
+		     ~(CLASS_SEC|VARIABLE_SEC| FUNCTION_SEC |UNION_SEC)},
 		    {"<DT><h3>Protected Classes</h3><DD>",PROT,CLASS_SEC|UNION_SEC},
 		    {"<DT><h3>Protected Fields</h3><DD>",PROT,VARIABLE_SEC},
 		    {"<DT><h3>Protected Methods</h3><DD>",PROT,FUNCTION_SEC},
 		    {"<DT><h3>Protected</h3><DD>",PROT,
-		     ~(CLASS_SEC|VARIABLE_SEC| FUNCTION_SEC)},
+		     ~(CLASS_SEC|VARIABLE_SEC| FUNCTION_SEC |UNION_SEC)},
 		    {"<DT><h3>Private Fields</h3><DD>",PRIV,VARIABLE_SEC},
 		    {"<DT><h3>Private Methods</h3><DD>",PRIV,FUNCTION_SEC},
 		    {"<DT><h3>Private</h3><DD>",PRIV,
-		     ~(CLASS_SEC|VARIABLE_SEC| FUNCTION_SEC)},
+		     ~(CLASS_SEC|VARIABLE_SEC| FUNCTION_SEC |UNION_SEC)},
 		    {0,0,0}};
 
     int first;
@@ -768,21 +771,23 @@ void showMembers( Entry *k,FILE *f,int links,MemberList *ignore=0)
 	memberWriter=new MemberWriter();
     }
     for (int i=0 ; sections[i].heading ; i++){
-	memberWriter->startList(f,sections[i].heading,links);
-	for( tmp = k->sub ; tmp ; tmp = tmp->next ) {
-	    if (tmp->protection==sections[i].protection && 
-		(tmp->section&sections[i].secMask)){
-		if (links || (strcmp(tmp->name,k->name)!=0
-			      && (((const char *)tmp->name)[0]!='~' || 
-				  strcmp(&((const char *)tmp->name)[1],k->name)!=0))){
-		  int ignoreThisOne = 0;		  
-		  if (ignore) {
-		    Entry* othersFather=ignore->addMember(tmp,k);
-		    if (othersFather!=0 && othersFather != k)
-		      ignoreThisOne=1;
-		  }
-		  if (!ignoreThisOne || links)
-		    memberWriter->addMember(tmp,links);
+	if (withPrivate || sections[i].protection!=PRIV) {
+	    memberWriter->startList(f,sections[i].heading,links);
+	    for( tmp = k->sub ; tmp ; tmp = tmp->next ) {
+		if (tmp->protection==sections[i].protection && 
+		    (tmp->section&sections[i].secMask)){
+		    if (links || (strcmp(tmp->name,k->name)!=0
+				  && (((const char *)tmp->name)[0]!='~' || 
+				      strcmp(&((const char *)tmp->name)[1],k->name)!=0))){
+			int ignoreThisOne = 0;		  
+			if (ignore) {
+			    Entry* othersFather=ignore->addMember(tmp,k);
+			    if (othersFather!=0 && othersFather != k)
+				ignoreThisOne=1;
+			}
+			if (!ignoreThisOne || links)
+			    memberWriter->addMember(tmp,links);
+		    }
 		}
 	    }
 	}
